/* GCC */

//#include<iostream>
#include<fstream>
#include<math.h>
#include<vector>
#include<list>

void markSubtreeAsVisited(int n, std::vector<std::list<int> > &tree, std::vector<bool> &visited, int root) {
    if (visited[root]) return;
    visited[root] = true;
    
    for (std::list<int>::iterator i = tree[root].begin(); i != tree[root].end(); i++)
        markSubtreeAsVisited(n, tree, visited, *i);
}

std::vector<int> findLoop(int n, std::vector<int> &parents, int start) {
    std::vector<bool> visited(n);
    int i = start;
    while (!visited[i]) {
        visited[i] = true;
        i = parents[i];
    }
    
    std::vector<int> res;
    int j = i;
    do {
        res.push_back(j);
        j = parents[j];
    } while (j != i);
    
    return res;
}

void removeLoop(int n, std::vector<int> &parents, std::vector<std::list<int> > &tree, std::vector<int> &loop) {
    for (std::vector<int>::iterator i = loop.begin(); i != loop.end(); i++) {
        //std::cout << *i << std::endl;
        tree[parents[*i]].remove(*i);
    }
}

std::pair<int, bool> processTree(int n, std::vector<std::list<int> > &tree, int root) {
    //std::cout << "processTree(" << n << ", [...], " << root << ")" << std::endl;
    int res = 0;
    bool flag = false;
    for (std::list<int>::iterator i = tree[root].begin(); i != tree[root].end(); i++) {
        std::pair<int, bool> t = processTree (n, tree, *i);
        res += t.first;
        flag |= t.second;
    }

    //std::cout << "(" << res + flag << "," << !flag << ")" << std::endl;
    return std::pair<int, bool>(res + flag, !flag);
}

int processComponent(int n, std::vector<int> &parents, std::vector<std::list<int> > &tree, std::vector<int> &loop) {
    int res = 0;
    
    bool flag = false;
    for (std::vector<int>::iterator i = loop.begin(); i != loop.end(); i++) {
        for (std::list<int>::iterator j = tree[*i].begin(); j != tree[*i].end(); j++) {
            std::pair<int, bool> t = processTree(n, tree, *j);
            res += t.first;
            flag |= !t.second;
        }
        //std::cout << res << std::endl;
    }
    
    int size = loop.size();
    if (size == 2) res += 2;
    else if (size % 2 == 1 && flag) res += size / 2 + 1;
    else res += size / 2;
    
    return res;
}

int main() {
    std::ifstream in("village.in");
    std::ofstream out("village.out");

    int n;
    
    in >> n;
    std::vector<int> parents(n);
    std::vector<std::list<int> > tree(n);
    for (int i = 0; i < n; i++) {
        in >> parents[i];
        parents[i]--;
        tree[parents[i]].push_back(i);
    }


    std::vector<bool> visited(n);
    int res = 0;
    for (int i = 0; i < n; i++) {
        if (!visited[i]) {
            std::vector<int> loop = findLoop(n, parents, i);
            markSubtreeAsVisited(n, tree, visited, loop[0]);
            removeLoop(n, parents, tree, loop);
            res += processComponent(n, parents, tree, loop);
        }
    }


    out << res << std::endl;
    //std::cout << res << std::endl;
    //std::cin.get();

    return 0;
}
